Esbonio Demo
------------

Welcome to the demo documentation site for the Esbonio language server!

.. Write a message here

This site is intended to complement the `Esbonio tutorial`_ and serve as an overview of all of the features provided by the language server.
For the best experience it's recommended that you view the source for the demo from your editor of choice - with the Esbonio language server enabled of course!

Like the tutorial, this demo site assumes that you are using VSCode so any keybindings/UI elements will be VSCode specific.
If you are using another editor, please refer to the documentation for your editor's LSP client for the corresponding information.

.. grid:: 2

   .. grid-item-card:: reStructuredText Demo
      :text-align: center
      :link: /demo_rst
      :link-type: doc

      Click to view the demo in reStructuredText format.

   .. grid-item-card:: MyST Demo
      :text-align: center
      :link: /demo_myst
      :link-type: doc

      Click to view the demo in MyST format.

.. toctree::
   :hidden:
   :caption: reStructuredText

   demo_rst

.. toctree::
   :hidden:
   :caption: MyST

   demo_myst

.. _Esbonio tutorial: https://docs.esbon.io/en/latest/lsp/getting-started.html
